==> piwigo-2.1.5.tbz: www/piwigo/plugins/LocalFilesEditor/language/it_IT/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configurazione locale';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Lingue';
$lang['locfiledit_onglet_plug'] = 'Plugin Personale';
$lang['locfiledit_cant_save'] = 'Non è stato possibile scrivere il file. Verificare i permessi (chmod) della directory "include/".';
$lang['locfiledit_newfile'] = 'Il file non esiste e sarà creato durante la fase di registrazione con LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Il file è stato salvato.';
$lang['locfiledit_show_default'] = 'Visualizzare il file ';
$lang['locfiledit_save_bak'] = 'Una copia di backup del file sarà creata durante la fase di registrazione';
$lang['locfiledit_saved_bak'] = 'Una copia di backup è stata creata (%s)';
$lang['locfiledit_save_file'] = 'Salvare il file';
$lang['locfiledit_choose_file'] = 'Scegliere un file da editare';
$lang['locfiledit_edit'] = 'Editare';
$lang['locfiledit_restore'] = 'Caricare il file di backup';
$lang['locfiledit_restore_confirm'] = 'Volete caricare il file di backup?
Dovrete in seguito cliccare sù Salvare per restaurarlo.';
$lang['locfiledit_bak_loaded1'] = 'Copia di backup caricata';
$lang['locfiledit_bak_loaded2'] = 'Dovete registrarlo per salvarlo.';
$lang['locfiledit_syntax_error'] = 'Errore di sintassi! Impossible salvare il file.';
$lang['locfiledit_enable_editarea'] = 'Attivare Editarea';
$lang['locfiledit_disable_editarea'] = 'Disattivare Editarea';
$lang['locfiledit_new_tpl'] = 'Creare un nuovo file';
$lang['locfiledit_new_filename'] = 'Nom file';
$lang['locfiledit_model'] = 'Modello';
$lang['locfiledit_empty_page'] = 'Pagina vergine';
$lang['locfiledit_parent_directory'] = 'Directory parente';
$lang['locfiledit_filename_error'] = 'Caratteri vietati nel nome del file.';
$lang['locfiledit_file_already_exists'] = 'Il file esiste già.';
$lang['locfiledit_model_error'] = 'Selezionare un modello.';
$lang['locfiledit_empty_filename'] = 'Indicate un nome di file.';
$lang['locfiledit_webmaster_only'] = 'Solo i webmasters sono autorizzati a creare o modificare i file locali.';

?>

==> piwigo-2.5.0.tbz: www/piwigo/plugins/LocalFilesEditor/language/it_IT/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configurazione locale';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Lingue';
$lang['locfiledit_onglet_plug'] = 'Plugin Personale';
$lang['locfiledit_cant_save'] = 'Non è stato possibile scrivere il file. Verificare i permessi di scrittura (chmod) della directory "local/".';
$lang['locfiledit_newfile'] = 'Il file non esiste fino a quando qualche informazione verrà inserita di seguito. Una volta che le informazioni sono inserite e salvate, il file verrà creato.';
$lang['locfiledit_save_config'] = 'Il file è stato salvato.';
$lang['locfiledit_show_default'] = 'Visualizzare il file ';
$lang['locfiledit_save_bak'] = 'Una copia di backup del file sarà creata durante la fase di salvataggio.';
$lang['locfiledit_saved_bak'] = 'Una copia di backup è stata creata (%s)';
$lang['locfiledit_save_file'] = 'Salvare il file';
$lang['locfiledit_choose_file'] = 'Scegliere un file da editare';
$lang['locfiledit_edit'] = 'Editare';
$lang['locfiledit_restore'] = 'Caricare il file di backup';
$lang['locfiledit_restore_confirm'] = 'Si prega di confermare?
Il ripristino non sarà effettivo fino al successivo salvataggio.';
$lang['locfiledit_bak_loaded1'] = 'Copia di backup caricata';
$lang['locfiledit_bak_loaded2'] = 'E\' necessario salvare il file per ripristinarlo.';
$lang['locfiledit_syntax_error'] = 'Errore di sintassi! Impossible salvare il file.';
$lang['locfiledit_new_tpl'] = 'Creare un nuovo file';
$lang['locfiledit_new_filename'] = 'Nome file';
$lang['locfiledit_model'] = 'Modello';
$lang['locfiledit_empty_page'] = 'Pagina vuota';
$lang['locfiledit_parent_directory'] = 'Directory parente';
$lang['locfiledit_filename_error'] = 'Caratteri vietati nel nome del file.';
$lang['locfiledit_file_already_exists'] = 'Il file esiste già.';
$lang['locfiledit_model_error'] = 'Selezionare un modello.';
$lang['locfiledit_empty_filename'] = 'Indicate un nome di file.';
$lang['locfiledit_webmaster_only'] = 'Solo i webmasters sono autorizzati a creare o modificare i file locali.';
?>
